@@ -45,6 +45,30 @@ def run_scheduler(arguments):
         os.system(f'taskkill /f /fi "WINDOWTITLE eq kill_current_terminal_window"')
 
 
+def do_scheduled_job(scheduler, program):
+    if not job_will_run(program):
+        return
+
+    scheduler.set_method_to_schedule(lambda: open_program(program.alias.value, program.path.value))
+    scheduler.process(
+        program.days.value,
+        program.time.value
+    )
+
+
+def job_will_run(program):
+    if not is_scheduled_today(program.days.value, program.alias.value, program.include.value, program.days.value, program.exclude.value):
+        return False
+
+    if is_time_to_stop(program.alias.value, program.time_to_stop.value):
+        return False
+
+    if not is_job_active(program.alias.value, program.status.value):
+        return False
+
+    return True
+
+
 def is_time_to_stop(program_name, time_to_stop):
     if time_to_stop != 'off'.lower():
         now = datetime.now()
@@ -56,9 +80,18 @@ def is_time_to_stop(program_name, time_to_stop):
     return False
 
 
-def is_scheduled_today(days_to_schedule):
-    now = datetime.now()
-    return now.strftime("%A").lower() in days_to_schedule
+def is_scheduled_today(days_to_schedule, program_name, included_days, days, excluded_days):
+    if is_included_day(program_name, included_days, days):
+        return True
+
+    if is_excluded_day(program_name, excluded_days):
+        return False
+
+    # this condition needs to be the last one
+    if datetime.now().strftime("%A").lower() not in days_to_schedule:
+        return False
+
+    return True
 
 
 def is_job_active(program_name, status):
@@ -69,41 +102,29 @@ def is_job_active(program_name, status):
 
 
 def is_excluded_day(program_name, excluded_days):
-    for date in excluded_days:
+    return check_days(program_name, excluded_days, ['not', 'excluded'])
+
+
+def is_included_day(program_name, included_days, days):
+    if check_days(program_name, included_days, ['', 'included']):
+        days.append(datetime.now().strftime("%A").lower())
+        return True
+    return False
+
+
+def check_days(program_name, days, message):
+    for date in days:
         saved_date = date.split('/')
-        validate_date = datetime(day=int(saved_date[0]), month=int(saved_date[1]), year=int(saved_date[2]))
+        validate_date = datetime(
+            day=int(saved_date[0]),
+            month=int(saved_date[1]),
+            year=int(saved_date[2])
+        )
         if validate_date == datetime.combine(datetime.today().date(), datetime.min.time()):
-            show('Today \"' + program_name + '\" will not run. ' + validate_date.strftime('%d/%m/%Y') + ' is an excluded date.')
+            show('Today \"' + program_name + '\" will ' + message[0] + ' run. ' + validate_date.strftime('%d/%m/%Y') + ' is an ' + message[1] + ' date.')
             return True
     return False
 
 
-def scheduled_job_invalid(program):
-    if not is_scheduled_today(program.days.value):
-        return True
-
-    if is_time_to_stop(program.alias.value, program.time_to_stop.value):
-        return True
-
-    if not is_job_active(program.alias.value, program.status.value):
-        return True
-
-    if is_excluded_day(program.alias.value, program.exclude.value):
-        return True
-
-    return False
-
-
-def do_scheduled_job(scheduler, program):
-    if scheduled_job_invalid(program):
-        return
-
-    scheduler.set_method_to_schedule(lambda: open_program(program.path.value))
-    scheduler.process(
-        program.days.value,
-        program.time.value
-    )
-
-
 if __name__ == '__main__':
     main()
